.. django_dicom documentation master file, created by
   sphinx-quickstart on Sat Apr 20 12:19:51 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django_dicom's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   installation
   quickstart
   user_guide/user_guide
   modules/reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
